=== modified file 'NEWS'
--- NEWS	2008-08-14 17:03:06 +0000
+++ NEWS	2008-08-14 18:55:46 +0000
@@ -11,6 +11,10 @@
 
   IMPROVEMENTS:
 
+    * ``bzr init`` and ``bzr init-repo`` will now print out the same as
+      ``bzr info`` if it completed successfully.
+      (Marius Kruger)
+
   BUG FIXES:
 
     * ``WorkingTree4`` trees will now correctly report missing-and-new

=== modified file 'bzrlib/builtins.py'
--- bzrlib/builtins.py	2008-08-11 03:39:25 +0000
+++ bzrlib/builtins.py	2008-08-14 17:08:56 +0000
@@ -1311,6 +1311,10 @@
             except errors.UpgradeRequired:
                 raise errors.BzrCommandError('This branch format cannot be set'
                     ' to append-revisions-only.  Try --experimental-branch6')
+        if not is_quiet():
+            from bzrlib.info import show_bzrdir_info
+            show_bzrdir_info(bzrdir.BzrDir.open_containing_from_transport(
+                to_transport)[0], verbose=0, outfile=self.outf)
 
 
 class cmd_init_repository(Command):
@@ -1362,6 +1366,10 @@
         newdir = format.initialize_on_transport(to_transport)
         repo = newdir.create_repository(shared=True)
         repo.set_make_working_trees(not no_trees)
+        if not is_quiet():
+            from bzrlib.info import show_bzrdir_info
+            show_bzrdir_info(bzrdir.BzrDir.open_containing_from_transport(
+                to_transport)[0], verbose=0, outfile=self.outf)
 
 
 class cmd_diff(Command):

=== modified file 'bzrlib/tests/blackbox/test_init.py'
--- bzrlib/tests/blackbox/test_init.py	2007-06-27 19:13:50 +0000
+++ bzrlib/tests/blackbox/test_init.py	2008-07-18 07:29:06 +0000
@@ -44,7 +44,10 @@
         # --format=weave should be accepted to allow interoperation with
         # old releases when desired.
         out, err = self.run_bzr('init --format=weave')
-        self.assertEqual('', out)
+        self.assertEqual("""Standalone tree (format: weave)
+Location:
+  branch root: .
+""", out)
         self.assertEqual('', err)
 
     def test_init_at_repository_root(self):
@@ -57,19 +60,32 @@
         repo = newdir.create_repository(shared=True)
         repo.set_make_working_trees(False)
         out, err = self.run_bzr('init repo')
-        self.assertEqual('', out)
+        self.assertEqual(
+"""Repository tree (format: pack-0.92)
+Location:
+  shared repository: repo
+  repository branch: repo
+""", out)
         self.assertEqual('', err)
         newdir.open_branch()
         newdir.open_workingtree()
         
     def test_init_branch(self):
         out, err = self.run_bzr('init')
-        self.assertEqual('', out)
+        self.assertEqual(
+"""Standalone tree (format: pack-0.92)
+Location:
+  branch root: .
+""", out)
         self.assertEqual('', err)
 
         # Can it handle subdirectories of branches too ?
         out, err = self.run_bzr('init subdir1')
-        self.assertEqual('', out)
+        self.assertEqual(
+"""Standalone tree (format: pack-0.92)
+Location:
+  branch root: subdir1
+""", out)
         self.assertEqual('', err)
         WorkingTree.open('subdir1')
         
@@ -80,13 +96,21 @@
         
         os.mkdir('subdir2')
         out, err = self.run_bzr('init subdir2')
-        self.assertEqual('', out)
+        self.assertEqual("""Standalone tree (format: pack-0.92)
+Location:
+  branch root: subdir2
+""", out)
         self.assertEqual('', err)
         # init an existing branch.
         out, err = self.run_bzr('init subdir2', retcode=3)
         self.assertEqual('', out)
         self.failUnless(err.startswith('bzr: ERROR: Already a branch:'))
 
+    def test_init_branch_quiet(self):
+        out, err = self.run_bzr('init -q')
+        self.assertEqual('', out)
+        self.assertEqual('', err)
+
     def test_init_existing_branch(self):
         self.run_bzr('init')
         out, err = self.run_bzr('init', retcode=3)
@@ -142,7 +166,9 @@
     def test_init(self):
         # init on a remote url should succeed.
         out, err = self.run_bzr(['init', self.get_url()])
-        self.assertEqual('', out)
+        self.assertStartsWith(out, """Standalone branch (format: pack-0.92)
+Location:
+  branch root: """)
         self.assertEqual('', err)
     
     def test_init_existing_branch(self):

=== modified file 'bzrlib/tests/blackbox/test_shared_repository.py'
--- bzrlib/tests/blackbox/test_shared_repository.py	2007-06-26 20:32:49 +0000
+++ bzrlib/tests/blackbox/test_shared_repository.py	2008-07-18 07:29:06 +0000
@@ -26,12 +26,25 @@
 
     def test_make_repository(self):
         out, err = self.run_bzr("init-repository a")
+        self.assertEqual(out,
+"""Shared repository with trees (format: pack-0.92)
+Location:
+  shared repository: a
+""")
+        self.assertEqual(err, "")
+        dir = BzrDir.open('a')
+        self.assertIs(dir.open_repository().is_shared(), True)
+        self.assertRaises(errors.NotBranchError, dir.open_branch)
+        self.assertRaises(errors.NoWorkingTree, dir.open_workingtree)
+
+    def test_make_repository_quiet(self):
+        out, err = self.run_bzr("init-repository a -q")
         self.assertEqual(out, "")
         self.assertEqual(err, "")
         dir = BzrDir.open('a')
         self.assertIs(dir.open_repository().is_shared(), True)
         self.assertRaises(errors.NotBranchError, dir.open_branch)
-        self.assertRaises(errors.NoWorkingTree, dir.open_workingtree)        
+        self.assertRaises(errors.NoWorkingTree, dir.open_workingtree)
 
     def test_init_repo_existing_dir(self):
         """Make repo in existing directory.

=== modified file 'bzrlib/tests/commands/test_init.py'
--- bzrlib/tests/commands/test_init.py	2007-09-11 14:47:02 +0000
+++ bzrlib/tests/commands/test_init.py	2008-07-16 20:24:50 +0000
@@ -15,6 +15,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 
+from bzrlib import tests
 from bzrlib.builtins import cmd_init
 from bzrlib.tests.transport_util import TestCaseWithConnectionHookedTransport
 
@@ -27,6 +28,8 @@
 
     def test_init(self):
         cmd = cmd_init()
+        # We don't care about the ouput but 'outf' should be defined
+        cmd.outf = tests.StringIOWrapper()
         cmd.run(self.get_url())
         self.assertEquals(1, len(self.connections))
 

=== modified file 'bzrlib/tests/commands/test_init_repository.py'
--- bzrlib/tests/commands/test_init_repository.py	2007-09-11 14:47:02 +0000
+++ bzrlib/tests/commands/test_init_repository.py	2008-07-16 20:24:50 +0000
@@ -15,6 +15,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 
+from bzrlib import tests
 from bzrlib.builtins import cmd_init_repository
 from bzrlib.tests.transport_util import TestCaseWithConnectionHookedTransport
 
@@ -27,6 +28,8 @@
 
     def test_init_repository(self):
         cmd = cmd_init_repository()
+        # We don't care about the ouput but 'outf' should be defined
+        cmd.outf = tests.StringIOWrapper()
         cmd.run(self.get_url())
         self.assertEquals(1, len(self.connections))
 

